#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.Indicators;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Strategies in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Strategies
{
	public class Zs8Random01 : Strategy
	{
        // Declaración del generador de números aleatorios:
        private Random myrandom;

		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"Estrategia de entradas aleatorias con salida por trailing bracket (profit + loss).";
				Name										= "Zs8Random01";
				Calculate									= Calculate.OnBarClose;
				EntriesPerDirection							= 1;
				EntryHandling								= EntryHandling.AllEntries;
				IsExitOnSessionCloseStrategy				= true;
				ExitOnSessionCloseSeconds					= 30;
				IsFillLimitOnTouch							= false;
				MaximumBarsLookBack							= MaximumBarsLookBack.TwoHundredFiftySix;
				OrderFillResolution							= OrderFillResolution.Standard;
				Slippage									= 0;
				StartBehavior								= StartBehavior.WaitUntilFlat;
				TimeInForce									= TimeInForce.Gtc;
				TraceOrders									= false;
				RealtimeErrorHandling						= RealtimeErrorHandling.StopCancelClose;
				StopTargetHandling							= StopTargetHandling.PerEntryExecution;
				BarsRequiredToTrade							= 20;
				// Disable this property for performance gains in Strategy Analyzer optimizations
				// See the Help Guide for additional information
				IsInstantiatedOnEachOptimizationIteration	= true;
				TrailingTicks = 20;
                ProfitTicks = 40;
			}
			else if (State == State.Configure)
			{
                SetTrailStop(CalculationMode.Ticks, TrailingTicks);
                SetProfitTarget(CalculationMode.Ticks, ProfitTicks);
			}
            else if (State == State.DataLoaded)
            {
                // Creo el generador de números aleatorios a partir de una semilla que es única:
                myrandom = new Random(Guid.NewGuid().GetHashCode());
            }
		}
        
        protected override void OnBarUpdate()
		{
            if (Position.MarketPosition == MarketPosition.Flat)
            {
                // Generación de un número entero entre 0 (inclusive) 
                // y 2 (no inclusive); o sea, entre 0 y 1 :
                Int32 n = myrandom.Next(0, 2);

                if (n == 0)
                {
                    EnterShort();
                }
                else if (n == 1)
                {
                    EnterLong();
                }
            }
        }

		#region Properties
		[Range(1, int.MaxValue)]
		[NinjaScriptProperty]
		[Display(ResourceType = typeof(Custom.Resource), Name="Profit Ticks", Description="Ticks de beneficio", Order=10, GroupName="NinjaScriptStrategyParameters")]
		public int ProfitTicks
		{ get; set; }

        [Range(1, int.MaxValue)]
        [NinjaScriptProperty]
        [Display(ResourceType = typeof(Custom.Resource), Name = "Trailing Ticks", Description = "Ticks para el trailing-stop", Order = 20, GroupName = "NinjaScriptStrategyParameters")]
        public int TrailingTicks
        { get; set; }

        #endregion

    }
}
